### Community Contributed Operational Tables and Views

This directory is meant to store contributed operational Table and View files.  At this point in the development of _Junos EZ_, these will likely be YAML files and their associated .py code.  For examples, refer to `jnpr/junos/op` files `phyport.yml` and `phyport.py`.

Thank you for your contributions!
